==> haskell-http-streams-0.8.6.1-53-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-1hldBmr5OCXER8ks4btmaV
key: http-streams-0.8.6.1-1hldBmr5OCXER8ks4btmaV
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: a5efadc7d7e18bc9516935ee7e633ac1
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-1hldBmr5OCXER8ks4btmaV
depends:
    attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-AvQko5t5W5NBDdx1IFCsfe
    HsOpenSSL-0.11.4.15-KO5b8lsGFom2uWEz5ZA000
    openssl-streams-1.2.1.3-8XW80ShvFf8B64uasiy19O mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo
    aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq
    http-common-0.8.2.0-C5nq3bR7JZt6Gy8E6PE8cU
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya
abi-depends: attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC=c6a831664a8826b2c70f720ac226f7d1
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             io-streams-1.5.0.1-AvQko5t5W5NBDdx1IFCsfe=683ddfb68dd0835c3d08dbf883cf0122
             HsOpenSSL-0.11.4.15-KO5b8lsGFom2uWEz5ZA000=5c3e6daaf835071c4b580853abcc3130
             openssl-streams-1.2.1.3-8XW80ShvFf8B64uasiy19O=c0e0d4e08df8ff559877f5d9350fb919
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-FkHC8tkjGhFEq6gcD4EsVo=64a561e4e9a96e6da50de53181f89cb1
             aeson-1.4.0.0-LGp6kTtgO3W1vagljwPVLq=0bddb8c122a0181e324f08c1b045cf5c
             http-common-0.8.2.0-C5nq3bR7JZt6Gy8E6PE8cU=f78da67ab7c1ad909df144c4b9ff9e6f
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya=34c8f87548d66d5af3596a33ad5000fc
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.6.1-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-3k58M1OMVdgBqUasDDI5lS
key: http-streams-0.8.6.1-3k58M1OMVdgBqUasDDI5lS
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 7289492764e5d537fdf9387891e0c331
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-3k58M1OMVdgBqUasDDI5lS
depends:
    attoparsec-0.13.2.2-EIztAESN4La3Q2n7ylOy7n base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-GCOrzZQqB5JAY8w1623kuX
    HsOpenSSL-0.11.4.15-rzkpI4xjHUfa0E9GTzov
    openssl-streams-1.2.1.3-G8ofObjFbQy5MdYvQyfcsm mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj
    aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b
    http-common-0.8.2.0-5N1tXaBeUxa2TYj1gQmr0q
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-2ShKE4Ejgp6Bq9Qkb7AIP
abi-depends: attoparsec-0.13.2.2-EIztAESN4La3Q2n7ylOy7n=5f8c3cf6b8ae475d94bd0da5607b091c
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             io-streams-1.5.0.1-GCOrzZQqB5JAY8w1623kuX=755c7f442ef398ff42969a099176d730
             HsOpenSSL-0.11.4.15-rzkpI4xjHUfa0E9GTzov=688cf5cf30d8be7a8e91acb95779e5f4
             openssl-streams-1.2.1.3-G8ofObjFbQy5MdYvQyfcsm=6a7ea9d66e98037f594f70bd1c937a78
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj=c333847eb697e0b9a0c6f4333fc78402
             aeson-1.4.0.0-1xR3EM2Xhm4Aau5GdgOB0b=c22e056a410eb876f6f97788d58417ce
             http-common-0.8.2.0-5N1tXaBeUxa2TYj1gQmr0q=d288ba8b394d87cca73442aab150549e
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             network-2.7.0.2-2ShKE4Ejgp6Bq9Qkb7AIP=febca036f4f0db50e6534d133a8b12c8
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
